@@ -3,7 +3,7 @@
 # vim:ft=sh:ts=8:sw=4:noet
 #
 # Hibernate Script
-# Copyright (C) 2004-2005 Bernard Blackham <bernard@blackham.com.au>
+# Copyright (C) 2004-2006 Bernard Blackham <bernard@blackham.com.au>
 #
 # The hibernate-script package is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as published by
@@ -56,12 +56,12 @@ unset TRIED_DASH
 
 SWSUSP_D="/etc/hibernate"
 SCRIPTLET_PATH="$SWSUSP_D/scriptlets.d /usr/local/share/hibernate/scriptlets.d /usr/share/hibernate/scriptlets.d"
-CONFIG_FILE="$SWSUSP_D/hibernate.conf"
+DEFAULT_CONFIG_FILE="$SWSUSP_D/hibernate.conf"
 EXE=`basename $0`
-VERSION="1.91"
+VERSION="1.93"
 
 # Add these to the $PATH just in case.
-PATH="$PATH:/sbin:/usr/sbin"
+PATH="$PATH:/sbin:/usr/sbin:/usr/local/sbin"
 export PATH
 
 # vecho N <echo params>: acts like echo but with verbosity control - If it's
@@ -461,21 +461,25 @@ DoGetOpt() {
 # ParseOptions <options>: process all the command-line options given
 ParseOptions() {
     local opts
-    opts="`getopt -n \"$EXE\" -o \"Vhfksv:nqF:$EXTRA_SHORT_OPTS\" -l \"help,force,kill,verbosity:,dry-run,config-file:$EXTRA_LONG_OPTS\" -- \"$@\"`" || exit 1
+    opts="`getopt -n \"$EXE\" -o \"Vhfksv:nqF:$EXTRA_SHORT_OPTS\" -l \"help,force,kill,verbosity:,dry-run,config-file:,version$EXTRA_LONG_OPTS\" -- \"$@\"`" || exit 1
     DoGetOpt $opts
 }
 
 # CheckImplicitAlternateConfig <$0> : checks $0 to see if we should be
 # implicitly using a different configuration file.
 CheckImplicitAlternateConfig() {
+    # Don't find one if we've already been specified one.
+    [ -n "$CONFIG_FILE" ] && return 0
+
     local self
     self=`basename $0`
     case $self in
 	hibernate-*) 
 	    CONFIG_FILE="$SWSUSP_D/${self#hibernate-}.conf"
-	    vecho 1 "Using implicit configuration file $CONFIG_FILE"
+	    vecho 3 "$EXE: Using implicit configuration file $CONFIG_FILE"
 	    ;;
 	*)
+	    CONFIG_FILE="${DEFAULT_CONFIG_FILE}"
 	    ;;
     esac
     return 0
@@ -485,17 +489,23 @@ CheckImplicitAlternateConfig() {
 # be dealt with before scriptlets and before other command-line options.
 PreliminaryGetopt() {
     local opt
-    local next_is_config
-    for opt in `getopt -q -o hF: -l help,config-file:,version -- "$@"` ; do
-	if [ -n "$next_is_config" ] ; then
-	    CONFIG_FILE="${opt#\'}"
-	    CONFIG_FILE="${CONFIG_FILE%\'}"
-	    next_is_config=
-	fi
+    set -- `getopt -q -o hv:F: -l help,verbosity:,config-file:,version -- "$@"`
+    while [ -n "$*" ] ; do
+	opt="$1"
+	shift
 
 	case $opt in
 	    -h|--help) HELP_ONLY=1 ;;
-	    -F|--config-file) next_is_config=1 ;;
+	    -F|--config-file)
+		CONFIG_FILE="${1#\'}"
+		CONFIG_FILE="${CONFIG_FILE%\'}"
+		;;
+	    -v|--verbosity)
+		OPT_VERBOSITY="${1#\'}"
+		OPT_VERBOSITY="${OPT_VERBOSITY%\'}"
+		EnsureNumeric "verbosity" $OPT_VERBOSITY && VERBOSITY="$OPT_VERBOSITY"
+		shift
+		;;
 	    --version)
 		echo "Hibernate Script $VERSION"
 		exit 0
@@ -623,15 +633,16 @@ ProcessConfigOption() {
 	    export DISPLAY
 	    ;;
         include)
-            if ! ReadConfigFile "$params" ; then
-                echo "$EXE: Unable to read configuration file $params (from Include directive)."
-                exit 1
-            fi
-            ;;
+	    vecho 3 "$EXE: Including configuration from $params"
+	    if ! ReadConfigFile "$params" ; then
+		echo "$EXE: Unable to read configuration file $params (from Include directive)."
+		exit 1
+	    fi
+	    ;;
 	trymethod)
 	    if [ -z "$HIBERNATE_SUSPEND_METHOD" ] ; then
 		NO_COMPLAIN_UNSUPPORTED=1
-		vecho 1 "Trying method in $2..."
+		vecho 1 "$EXE: Trying method in $1..."
 		if ! ReadConfigFile "$params" ; then
 		    echo "$EXE: Unable to read configuration file $params (from TryMethod directive)."
 		fi
@@ -788,11 +799,11 @@ ERROR_TEXT=""
 
 EnsureHavePrerequisites
 
-CheckImplicitAlternateConfig $0
-
-# Test for options that will affect future choices (-h and -F currently)
+# Test for options that will affect future choices
 PreliminaryGetopt "$@"
 
+CheckImplicitAlternateConfig $0
+
 # Generating help text is slow. Avoid it if we can.
 if [ -n "$HELP_ONLY" ] ; then
     AddInbuiltHelp
@@ -854,4 +865,4 @@ echo "Resumed at "`date` | $LOGPIPE > /dev/null
 
 exit $EXIT_CODE
 
-# $Id: hibernate.sh 1027 2006-06-05 11:20:36Z bernard $
+# $Id: hibernate.sh 1052 2006-07-12 10:15:00Z bernard $
