@@ -18,7 +18,7 @@ HIBERNATE_FILEWRITER_TRAIL="/var/run/suspend2_filewriter_image_exists"
 
 get_swap_id() {
 	local line
-	fdisk -l | while read line; do
+	fdisk -l 2>/dev/null | while read line; do
 		case "$line" in
 			/*Linux\ [sS]wap*) echo "${line%% *}"
 		esac
@@ -66,9 +66,17 @@ check_filewriter_sig() {
 	esac
 }
 
-echo -n "Clearing Software Suspend 2 signatures... "
-check_swap_sig
-check_filewriter_sig
-echo "done."
+case "$1" in
+start)
+        echo -n "Invalidating stale software suspend images... "
+        check_swap_sig
+        check_filewriter_sig
+        echo "done."
+        ;;
+stop|restart|force-reload)
+        ;;
+*)
+        echo "Usage: /etc/init.d/hibernate {start|stop|restart|force-reload}"
+esac
 
 exit 0
